@@ -1,14 +1,11 @@
-require(RGtk2)
-
-#debug(gClass)
-tform_scale_type <- gClass("RTransformedHScale", "GtkHScale", list(
+tform_scale_type <- gClass("RTransformedHScale", "GtkHScale",
   .props = list(
     gParamSpec("R", "expr", "e", "Transformation of scale value",
       default.value = expression(x))
   ),
   .public = list(
     getExpr = function(self) self["expr"],
-    getTransformedValue = function(self) self$transformValue(self$value)
+    getTransformedValue = function(self) self$transformValue(self$getValue())
   ),
   .private = list(
     transformValue = function(self, x) eval(self$expr, list(x = x))
@@ -17,7 +14,7 @@ tform_scale_type <- gClass("RTransformedHScale", "GtkHScale", list(
     format_value = function(self, x)
       as.character(self$transformValue(x))
   )
-))
+)
 
 
 adj <- gtkAdjustment(0.5, 0.15, 1.00, 0.05, 0.5, 0)
@@ -34,7 +31,7 @@ gSignalConnect(s, "value-changed", function(scale) {
 n <- 5000
 backbone <- rnorm(n)
 ma_data <- cbind(backbone, backbone+rnorm(n,,0.3))
-require(cairoDevice)
+library(cairoDevice)
 win <- gtkWindow(show = F)
 da <- gtkDrawingArea()
 asCairoDevice(da)
